import typing
import json
import re
import os
import httpx

from typing import Iterator, Optional, Union, \
  Optional, AsyncIterator

from .base_client import \
  BaseElevenLabs, AsyncBaseElevenLabs
from .core import RequestOptions, ApiError
from .types import Voice, VoiceSettings, \
  PronunciationDictionaryVersionLocator, Model
from .environment import ElevenLabsEnvironment
from .realtime_tts import RealtimeTextToSpeechClient
from .types import OutputFormat


DEFAULT_VOICE = Voice(
    voice_id="EXAVITQu4vr4xnSDxMaL",
    name="Sarah",
    settings=VoiceSettings(
        stability=0.71, similarity_boost=0.5, style=0.0, use_speaker_boost=True
    ),
)

VoiceId = str

VoiceName = str

ModelId = str


def is_voice_id(val: str) -> bool:
    return bool(re.match(r"^[a-zA-Z0-9]{20}$", val))


def get_base_url_host(base_url: str) -> str:
    return httpx.URL(base_url).host


# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ElevenLabs(BaseElevenLabs):
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propogate to these functions.

    Parameters:
        - base_url: typing.Optional[str]. The base url to use for requests from the client.

        - environment: ElevenLabsEnvironment. The environment to use for requests from the client. from .environment import ElevenLabsEnvironment

                                              Defaults to ElevenLabsEnvironment.PRODUCTION

        - api_key: typing.Optional[str].

        - timeout: typing.Optional[float]. The timeout to be used, in seconds, for requests by default the timeout is 60 seconds.

        - httpx_client: typing.Optional[httpx.Client]. The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.
    ---
    from elevenlabs.client import ElevenLabs

    client = ElevenLabs(
        api_key="YOUR_API_KEY",
    )
    """
    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ElevenLabsEnvironment = ElevenLabsEnvironment.PRODUCTION,
        api_key: typing.Optional[str] = os.getenv("ELEVENLABS_API_KEY"),
        timeout: typing.Optional[float] = 60,
        httpx_client: typing.Optional[httpx.Client] = None
    ):
        super().__init__(
            environment=base_url
            and ElevenLabsEnvironment(
                base=f"https://{get_base_url_host(base_url)}",
                wss=f"wss://{get_base_url_host(base_url)}",
            )
            or environment,
            api_key=api_key,
            timeout=timeout,
            httpx_client=httpx_client
        )
        self.text_to_speech = RealtimeTextToSpeechClient(client_wrapper=self._client_wrapper)

    def clone(
      self,
      name: str,
      files: typing.List[str],
      description: str,
      labels: typing.Optional[str] = None,
      request_options: typing.Optional[RequestOptions] = None
    ) -> Voice:
        """
          This is a manually maintained helper function that clones a voice from a set of audio files.
          **NOTE**: This function is a helper function and is simply making
          calls to the `add` and `get` functions of the `voices` endpoint.

          Parameters:
              - name: str. The name that identifies this voice. This will be displayed in the dropdown of the website.

              - files: typing.List[str]. The filepaths of the audio files to be used to create the voice.

              - description: str. How would you describe the voice?

              - labels: str. Serialized labels dictionary for the voice.

              - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        """
        add_voice_response = self.voices.add(
          name=name,
          description=description,
          files=[open(file, 'rb') for file in files],
          labels=str(json.dumps(labels or {}))
        )
        return self.voices.get(
          add_voice_response.voice_id,
          request_options=request_options
        )

    def generate(
      self,
      *,
      text: Union[str, Iterator[str]],
      voice: Union[VoiceId, VoiceName, Voice] = DEFAULT_VOICE,
      voice_settings: typing.Optional[VoiceSettings] = DEFAULT_VOICE.settings,
      model: Union[ModelId, Model] = "eleven_multilingual_v2",
      optimize_streaming_latency: typing.Optional[int] = 0,
      stream: bool = False,
      output_format: Optional[OutputFormat] = "mp3_44100_128",
      pronunciation_dictionary_locators: typing.Optional[
            typing.Sequence[PronunciationDictionaryVersionLocator]
        ] = OMIT,
      request_options: typing.Optional[RequestOptions] = None
    ) -> Iterator[bytes]:
        """
            - text: Union[str, Iterator[str]]. The string or stream of strings that will get converted into speech.

            - voice: str. A voice id, name, or voice response. Defaults to the Sarah voice.

            - model: typing.Optional[str]. Identifier of the model that will be used, you can query them using GET /v1/models.
                                           The model needs to have support for text to speech, you can check this using the
                                           can_do_text_to_speech property.

            - optimize_streaming_latency: typing.Optional[int]. You can turn on latency optimizations at some cost of quality. The best possible final latency varies by model. Possible values:
                                                                0 - default mode (no latency optimizations)
                                                                1 - normal latency optimizations (about 50% of possible latency improvement of option 3)
                                                                2 - strong latency optimizations (about 75% of possible latency improvement of option 3)
                                                                3 - max latency optimizations
                                                                4 - max latency optimizations, but also with text normalizer turned off for even more latency savings (best latency, but can mispronounce eg numbers and dates).

                                                                Defaults to 0.

            - stream: bool. If true, the function will return a generator that will yield the audio in chunks.

                            Defaults to False.

            - output_format: typing.Optional[OutputFormat]. Output format of the generated audio. Must be one of:
                                                   mp3_22050_32 - output format, mp3 with 22.05kHz sample rate at 32kbps.
                                                   mp3_44100_32 - output format, mp3 with 44.1kHz sample rate at 32kbps.
                                                   mp3_44100_64 - output format, mp3 with 44.1kHz sample rate at 64kbps.
                                                   mp3_44100_96 - output format, mp3 with 44.1kHz sample rate at 96kbps.
                                                   mp3_44100_128 - default output format, mp3 with 44.1kHz sample rate at 128kbps.
                                                   mp3_44100_192 - output format, mp3 with 44.1kHz sample rate at 192kbps. Requires you to be subscribed to Creator tier or above.
                                                   pcm_16000 - PCM format (S16LE) with 16kHz sample rate.
                                                   pcm_22050 - PCM format (S16LE) with 22.05kHz sample rate.
                                                   pcm_24000 - PCM format (S16LE) with 24kHz sample rate.
                                                   pcm_44100 - PCM format (S16LE) with 44.1kHz sample rate. Requires you to be subscribed to Independent Publisher tier or above.
                                                   ulaw_8000 - μ-law format (sometimes written mu-law, often approximated as u-law) with 8kHz sample rate. Note that this format is commonly used for Twilio audio inputs.

                                                    Defaults to mp3_44100_128.

            - voice_settings: typing.Optional[VoiceSettings]. Voice settings overriding stored setttings for the given voice. They are applied only on the given request.

            - pronunciation_dictionary_locators: typing.Optional[typing.Sequence[PronunciationDictionaryVersionLocator]]. A list of pronunciation dictionary locators (id, version_id) to be applied to the text. They will be applied in order. You may have up to 3 locators per request

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        """
        if isinstance(voice, str) and is_voice_id(voice):
            voice_id = voice
        elif isinstance(voice, str):
            voices_response = self.voices.get_all(request_options=request_options, show_legacy=True)
            maybe_voice_id = next((v.voice_id for v in voices_response.voices if v.name == voice), None)
            if maybe_voice_id is None:
                raise ApiError(body=f"Voice {voice} not found.")
            voice_id = maybe_voice_id
        elif isinstance(voice, Voice):
            voice_id = voice.voice_id
            if voice_settings == DEFAULT_VOICE.settings \
                    and voice.settings is not None:
                voice_settings = voice.settings
        else:
            voice_id = DEFAULT_VOICE.voice_id

        if isinstance(model, str):
            model_id = model
        elif isinstance(model, Model):
            model_id = model.model_id


        if stream:
            if isinstance(text, str):
                return self.text_to_speech.convert_as_stream(
                    voice_id=voice_id,
                    voice_settings=voice_settings,
                    optimize_streaming_latency=optimize_streaming_latency,
                    output_format=output_format,
                    text=text,
                    request_options=request_options,
                    pronunciation_dictionary_locators=pronunciation_dictionary_locators,
                    model_id=model_id
                )
            elif isinstance(text, Iterator):
                return self.text_to_speech.convert_realtime(  # type: ignore
                    voice_id=voice_id,
                    voice_settings=voice_settings,
                    output_format=output_format,
                    text=text,
                    request_options=request_options,
                    model_id=model_id
                )
            else:
                raise ApiError(body="Text is neither a string nor an iterator.")
        else:
            if not isinstance(text, str):
                raise ApiError(body="Text must be a string when stream is False.")
            return self.text_to_speech.convert(
                voice_id=voice_id,
                model_id=model_id,
                voice_settings=voice_settings,
                optimize_streaming_latency=optimize_streaming_latency,
                output_format=output_format,
                text=text,
                request_options=request_options,
                pronunciation_dictionary_locators=pronunciation_dictionary_locators
            )


class AsyncElevenLabs(AsyncBaseElevenLabs):
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propogate to these functions.

    Parameters:
        - base_url: typing.Optional[str]. The base url to use for requests from the client.

        - environment: ElevenLabsEnvironment. The environment to use for requests from the client. from .environment import ElevenLabsEnvironment

                                              Defaults to ElevenLabsEnvironment.PRODUCTION

        - api_key: typing.Optional[str].

        - timeout: typing.Optional[float]. The timeout to be used, in seconds, for requests by default the timeout is 60 seconds.

        - httpx_client: typing.Optional[httpx.AsyncClient]. The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.
    ---
    from elevenlabs.client import AsyncElevenLabs

    client = AsyncElevenLabs(
        api_key="YOUR_API_KEY",
    )
    """

    async def clone(
      self,
      name: str,
      files: typing.List[str],
      description: str,
      labels: str,
      request_options: typing.Optional[RequestOptions] = None
    ) -> Voice:
        """
          This is a manually mnaintained helper function that generates a
          voice from provided text.

          **NOTE**: This function is a helper function and is simply making
          calls to the `text_to_speech.convert` and`text_to_speech.convert_as_stream`
          functions.

          Parameters:
              - name: str. The name that identifies this voice. This will be displayed in the dropdown of the website.

              - files: typing.List[str]. The filepaths of the audio files to be used to create the voice.

              - description: str. How would you describe the voice?

              - labels: str. Serialized labels dictionary for the voice.

              - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        """
        add_voice_response = await self.voices.add(
          name=name,
          description=description,
          files=[open(file, 'rb') for file in files],
          labels=str(json.dumps(labels or {}))
        )
        return await self.voices.get(
          add_voice_response.voice_id,
          request_options=request_options
        )

    async def generate(
      self,
      *,
      text: str,
      voice: Union[VoiceId, VoiceName, Voice] = DEFAULT_VOICE,
      voice_settings: typing.Optional[VoiceSettings] = DEFAULT_VOICE.settings,
      model: Union[ModelId, Model] = "eleven_multilingual_v2",
      optimize_streaming_latency: typing.Optional[int] = 0,
      stream: bool = False,
      output_format: Optional[OutputFormat] = "mp3_44100_128",
      pronunciation_dictionary_locators: typing.Optional[
            typing.Sequence[PronunciationDictionaryVersionLocator]
        ] = OMIT,
      request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncIterator[bytes]:
        """
          This is a manually mnaintained helper function that generates a
          voice from provided text.

          **NOTE**: This function is a helper function and is simply making
          calls to the `text_to_speech.convert` and`text_to_speech.convert_as_stream`
          functions.

            - text: str. The string that will get converted into speech. The Async client does not support streaming.

            - voice: str. A voice id, name, or voice response. Defaults to the Rachel voice.

            - model: typing.Optional[str]. Identifier of the model that will be used, you can query them using GET /v1/models.
                                           The model needs to have support for text to speech, you can check this using the
                                           can_do_text_to_speech property.

            - optimize_streaming_latency: typing.Optional[int]. You can turn on latency optimizations at some cost of quality. The best possible final latency varies by model. Possible values:
                                                                0 - default mode (no latency optimizations)
                                                                1 - normal latency optimizations (about 50% of possible latency improvement of option 3)
                                                                2 - strong latency optimizations (about 75% of possible latency improvement of option 3)
                                                                3 - max latency optimizations
                                                                4 - max latency optimizations, but also with text normalizer turned off for even more latency savings (best latency, but can mispronounce eg numbers and dates).

                                                                Defaults to 0.

            - stream: bool. If true, the function will return a generator that will yield the audio in chunks.

                            Defaults to False.

            - output_format: typing.Optional[OutputFormat]. Output format of the generated audio. Must be one of:
                                                   mp3_22050_32 - output format, mp3 with 22.05kHz sample rate at 32kbps.
                                                   mp3_44100_32 - output format, mp3 with 44.1kHz sample rate at 32kbps.
                                                   mp3_44100_64 - output format, mp3 with 44.1kHz sample rate at 64kbps.
                                                   mp3_44100_96 - output format, mp3 with 44.1kHz sample rate at 96kbps.
                                                   mp3_44100_128 - default output format, mp3 with 44.1kHz sample rate at 128kbps.
                                                   mp3_44100_192 - output format, mp3 with 44.1kHz sample rate at 192kbps. Requires you to be subscribed to Creator tier or above.
                                                   pcm_16000 - PCM format (S16LE) with 16kHz sample rate.
                                                   pcm_22050 - PCM format (S16LE) with 22.05kHz sample rate.
                                                   pcm_24000 - PCM format (S16LE) with 24kHz sample rate.
                                                   pcm_44100 - PCM format (S16LE) with 44.1kHz sample rate. Requires you to be subscribed to Independent Publisher tier or above.
                                                   ulaw_8000 - μ-law format (sometimes written mu-law, often approximated as u-law) with 8kHz sample rate. Note that this format is commonly used for Twilio audio inputs.

                                                    Defaults to mp3_44100_128.

            - voice_settings: typing.Optional[VoiceSettings]. Voice settings overriding stored setttings for the given voice. They are applied only on the given request.

            - pronunciation_dictionary_locators: typing.Optional[typing.Sequence[PronunciationDictionaryVersionLocator]]. A list of pronunciation dictionary locators (id, version_id) to be applied to the text. They will be applied in order. You may have up to 3 locators per request

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        """
        if isinstance(voice, str) and is_voice_id(voice):
            voice_id = voice
        elif isinstance(voice, str):
            voices_response = await self.voices.get_all(request_options=request_options, show_legacy=True)
            maybe_voice_id = next((v.voice_id for v in voices_response.voices if v.name == voice), None)
            if not maybe_voice_id:
                raise ApiError(body=f"Voice {voice} not found.")
            voice_id = maybe_voice_id
        elif isinstance(voice, Voice):
            voice_id = voice.voice_id
            if voice_settings == DEFAULT_VOICE.settings \
                    and voice.settings is not None:
                voice_settings = voice.settings
        else:
            voice_id = DEFAULT_VOICE.voice_id

        if isinstance(model, str):
            model_id = model
        elif isinstance(model, Model):
            model_id = model.model_id

        if stream:
            return self.text_to_speech.convert_as_stream(
                voice_id=voice_id,
                model_id=model_id,
                voice_settings=voice_settings,
                optimize_streaming_latency=optimize_streaming_latency,
                output_format=output_format,
                text=text,
                request_options=request_options,
                pronunciation_dictionary_locators=pronunciation_dictionary_locators
            )
        else:
            if not isinstance(text, str):
                raise ApiError(body="Text must be a string when stream is False.")
            return self.text_to_speech.convert(
                voice_id=voice_id,
                model_id=model_id,
                voice_settings=voice_settings,
                optimize_streaming_latency=optimize_streaming_latency,
                output_format=output_format,
                text=text,
                request_options=request_options,
                pronunciation_dictionary_locators=pronunciation_dictionary_locators
            )



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property_output import ArrayJsonSchemaPropertyOutput
from .object_json_schema_property_output import ObjectJsonSchemaPropertyOutput
import pydantic
from .conversational_config_api_model_output import ConversationalConfigApiModelOutput
from .agent_metadata_response_model import AgentMetadataResponseModel
import typing
from .agent_platform_settings_response_model import AgentPlatformSettingsResponseModel
from .get_phone_number_response_model import GetPhoneNumberResponseModel
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class GetAgentResponseModel(UncheckedBaseModel):
    agent_id: str = pydantic.Field()
    """
    The ID of the agent
    """

    name: str = pydantic.Field()
    """
    The name of the agent
    """

    conversation_config: ConversationalConfigApiModelOutput = pydantic.Field()
    """
    The conversation configuration of the agent
    """

    metadata: AgentMetadataResponseModel = pydantic.Field()
    """
    The metadata of the agent
    """

    platform_settings: typing.Optional[AgentPlatformSettingsResponseModel] = pydantic.Field(default=None)
    """
    The platform settings of the agent
    """

    phone_numbers: typing.Optional[typing.List[GetPhoneNumberResponseModel]] = pydantic.Field(default=None)
    """
    The phone numbers of the agent
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
from .share_option_response_model_type import ShareOptionResponseModelType
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class ShareOptionResponseModel(UncheckedBaseModel):
    name: str = pydantic.Field()
    """
    The name of the principal.
    """

    id: str = pydantic.Field()
    """
    The ID of the principal.
    """

    type: ShareOptionResponseModelType = pydantic.Field()
    """
    The type of the principal: user, group, or workspace api key.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from .speaker_separation_response_model import SpeakerSeparationResponseModel
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class VoiceSample(UncheckedBaseModel):
    sample_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The ID of the sample.
    """

    file_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the sample file.
    """

    mime_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The MIME type of the sample file.
    """

    size_bytes: typing.Optional[int] = pydantic.Field(default=None)
    """
    The size of the sample file in bytes.
    """

    hash: typing.Optional[str] = pydantic.Field(default=None)
    """
    The hash of the sample file.
    """

    duration_secs: typing.Optional[float] = None
    remove_background_noise: typing.Optional[bool] = None
    has_isolated_audio: typing.Optional[bool] = None
    has_isolated_audio_preview: typing.Optional[bool] = None
    speaker_separation: typing.Optional[SpeakerSeparationResponseModel] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

SubscriptionStatus = typing.Union[
    typing.Literal[
        "trialing",
        "active",
        "incomplete",
        "incomplete_expired",
        "past_due",
        "canceled",
        "unpaid",
        "free",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .speaker_separation_response_model_status import (
    SpeakerSeparationResponseModelStatus,
)
import typing
from .speaker_response_model import SpeakerResponseModel
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class SpeakerSeparationResponseModel(UncheckedBaseModel):
    voice_id: str
    sample_id: str
    status: SpeakerSeparationResponseModelStatus
    speakers: typing.Optional[typing.Dict[str, typing.Optional[SpeakerResponseModel]]] = None
    selected_speaker_ids: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .projects_add_request_apply_text_normalization import ProjectsAddRequestApplyTextNormalization
from .projects_add_request_fiction import ProjectsAddRequestFiction
from .projects_add_request_source_type import ProjectsAddRequestSourceType
from .projects_add_request_target_audience import ProjectsAddRequestTargetAudience

__all__ = [
    "ProjectsAddRequestApplyTextNormalization",
    "ProjectsAddRequestFiction",
    "ProjectsAddRequestSourceType",
    "ProjectsAddRequestTargetAudience",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class SubscriptionUsageResponseModel(UncheckedBaseModel):
    rollover_credits_quota: int = pydantic.Field()
    """
    The rollover credits quota.
    """

    subscription_cycle_credits_quota: int = pydantic.Field()
    """
    The subscription cycle credits quota.
    """

    manually_gifted_credits_quota: int = pydantic.Field()
    """
    The manually gifted credits quota.
    """

    rollover_credits_used: int = pydantic.Field()
    """
    The rollover credits used.
    """

    subscription_cycle_credits_used: int = pydantic.Field()
    """
    The subscription cycle credits used.
    """

    manually_gifted_credits_used: int = pydantic.Field()
    """
    The manually gifted credits used.
    """

    paid_usage_based_credits_used: int = pydantic.Field()
    """
    The paid usage based credits used.
    """

    actual_reported_credits: int = pydantic.Field()
    """
    The actual reported credits.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class PydanticPronunciationDictionaryVersionLocator(UncheckedBaseModel):
    """
    A locator for other documents to be able to reference a specific dictionary and it's version.
    This is a pydantic version of PronunciationDictionaryVersionLocatorDBModel.
    Required to ensure compat with the rest of the agent data models.
    """

    pronunciation_dictionary_id: str = pydantic.Field()
    """
    The ID of the pronunciation dictionary
    """

    version_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The ID of the version of the pronunciation dictionary
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .telephony_provider import TelephonyProvider
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class CreateTwilioPhoneNumberRequest(UncheckedBaseModel):
    phone_number: str = pydantic.Field()
    """
    Phone number
    """

    provider: typing.Optional[TelephonyProvider] = None
    label: str = pydantic.Field()
    """
    Label for the phone number
    """

    sid: str = pydantic.Field()
    """
    Twilio Account SID
    """

    token: str = pydantic.Field()
    """
    Twilio Auth Token
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class AudioNativeCreateProjectResponseModel(UncheckedBaseModel):
    project_id: str = pydantic.Field()
    """
    The ID of the created Audio Native project.
    """

    converting: bool = pydantic.Field()
    """
    Whether the project is currently being converted.
    """

    html_snippet: str = pydantic.Field()
    """
    The HTML snippet to embed the Audio Native player.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .voice_generation_parameter_option_response import (
    VoiceGenerationParameterOptionResponse,
)
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class VoiceGenerationParameterResponse(UncheckedBaseModel):
    genders: typing.List[VoiceGenerationParameterOptionResponse]
    accents: typing.List[VoiceGenerationParameterOptionResponse]
    ages: typing.List[VoiceGenerationParameterOptionResponse]
    minimum_characters: int
    maximum_characters: int
    minimum_accent_strength: float
    maximum_accent_strength: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .prompt_evaluation_criteria import PromptEvaluationCriteria
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class EvaluationSettings(UncheckedBaseModel):
    """
    Settings to evaluate an agent's performance.
    Agents are evaluated against a set of criteria, with success being defined as meeting some combination of those criteria.
    """

    criteria: typing.Optional[typing.List[PromptEvaluationCriteria]] = pydantic.Field(default=None)
    """
    Individual criteria that the agent should be evaluated against
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SpeechToTextCharacterResponseModel(UncheckedBaseModel):
    text: str = pydantic.Field()
    """
    The character that was transcribed.
    """

    start: typing.Optional[float] = pydantic.Field(default=None)
    """
    The start time of the character in seconds.
    """

    end: typing.Optional[float] = pydantic.Field(default=None)
    """
    The end time of the character in seconds.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess,
    PronunciationDictionaryAddFromFileRequestWorkspaceAccess,
    PronunciationDictionaryGetAllRequestSort,
    PronunciationDictionaryRule,
    PronunciationDictionaryRule_Alias,
    PronunciationDictionaryRule_Phoneme,
)

__all__ = [
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess",
    "PronunciationDictionaryAddFromFileRequestWorkspaceAccess",
    "PronunciationDictionaryGetAllRequestSort",
    "PronunciationDictionaryRule",
    "PronunciationDictionaryRule_Alias",
    "PronunciationDictionaryRule_Phoneme",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.workspace_group_by_name_response_model import (
    WorkspaceGroupByNameResponseModel,
)
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.delete_workspace_group_member_response_model import (
    DeleteWorkspaceGroupMemberResponseModel,
)
from ..core.jsonable_encoder import jsonable_encoder
from ..types.add_workspace_group_member_response_model import (
    AddWorkspaceGroupMemberResponseModel,
)
from ..types.add_workspace_invite_response_model import AddWorkspaceInviteResponseModel
from ..types.delete_workspace_invite_response_model import (
    DeleteWorkspaceInviteResponseModel,
)
from .types.body_update_member_v_1_workspace_members_post_workspace_role import (
    BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole,
)
from ..types.update_workspace_member_response_model import (
    UpdateWorkspaceMemberResponseModel,
)
from ..types.workspace_resource_type import WorkspaceResourceType
from ..types.resource_metadata_response_model import ResourceMetadataResponseModel
from .types.body_share_workspace_resource_v_1_workspace_resources_resource_id_share_post_role import (
    BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
)
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class WorkspaceClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def search_user_groups(
        self, *, name: str, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[WorkspaceGroupByNameResponseModel]:
        """
        Searches for user groups in the workspace. Multiple or no groups may be returned.

        Parameters
        ----------
        name : str
            Name of the target group.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[WorkspaceGroupByNameResponseModel]
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.search_user_groups(
            name="name",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/workspace/groups/search",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "name": name,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[WorkspaceGroupByNameResponseModel],
                    construct_type(
                        type_=typing.List[WorkspaceGroupByNameResponseModel],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_member_from_user_group(
        self,
        group_id: str,
        *,
        email: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DeleteWorkspaceGroupMemberResponseModel:
        """
        Removes a member from the specified group. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        group_id : str
            The ID of the target group.

        email : str
            The email of the target workspace member.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteWorkspaceGroupMemberResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.delete_member_from_user_group(
            group_id="group_id",
            email="email",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/workspace/groups/{jsonable_encoder(group_id)}/members/remove",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "email": email,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DeleteWorkspaceGroupMemberResponseModel,
                    construct_type(
                        type_=DeleteWorkspaceGroupMemberResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def add_member_to_user_group(
        self,
        group_id: str,
        *,
        email: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddWorkspaceGroupMemberResponseModel:
        """
        Adds a member of your workspace to the specified group. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        group_id : str
            The ID of the target group.

        email : str
            The email of the target workspace member.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddWorkspaceGroupMemberResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.add_member_to_user_group(
            group_id="group_id",
            email="email",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/workspace/groups/{jsonable_encoder(group_id)}/members",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "email": email,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddWorkspaceGroupMemberResponseModel,
                    construct_type(
                        type_=AddWorkspaceGroupMemberResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def invite_user(
        self,
        *,
        email: str,
        group_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddWorkspaceInviteResponseModel:
        """
        Sends an email invitation to join your workspace to the provided email. If the user doesn't have an account they will be prompted to create one. If the user accepts this invite they will be added as a user to your workspace and your subscription using one of your seats. This endpoint may only be called by workspace administrators. If the user is already in the workspace a 400 error will be returned.

        Parameters
        ----------
        email : str
            The email of the customer

        group_ids : typing.Optional[typing.Sequence[str]]
            The group ids of the user

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddWorkspaceInviteResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.invite_user(
            email="john.doe@testmail.com",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/workspace/invites/add",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "email": email,
                "group_ids": group_ids,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddWorkspaceInviteResponseModel,
                    construct_type(
                        type_=AddWorkspaceInviteResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def invite_multiple_users(
        self,
        *,
        emails: typing.Sequence[str],
        group_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddWorkspaceInviteResponseModel:
        """
        Sends email invitations to join your workspace to the provided emails. Requires all email addresses to be part of a verified domain. If the users don't have an account they will be prompted to create one. If the users accept these invites they will be added as users to your workspace and your subscription using one of your seats. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        emails : typing.Sequence[str]
            The email of the customer

        group_ids : typing.Optional[typing.Sequence[str]]
            The group ids of the user

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddWorkspaceInviteResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.invite_multiple_users(
            emails=["emails"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/workspace/invites/add-bulk",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "emails": emails,
                "group_ids": group_ids,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddWorkspaceInviteResponseModel,
                    construct_type(
                        type_=AddWorkspaceInviteResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_existing_invitation(
        self, *, email: str, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteWorkspaceInviteResponseModel:
        """
        Invalidates an existing email invitation. The invitation will still show up in the inbox it has been delivered to, but activating it to join the workspace won't work. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        email : str
            The email of the customer

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteWorkspaceInviteResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.delete_existing_invitation(
            email="john.doe@testmail.com",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/workspace/invites",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            json={
                "email": email,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DeleteWorkspaceInviteResponseModel,
                    construct_type(
                        type_=DeleteWorkspaceInviteResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_member(
        self,
        *,
        email: str,
        is_locked: typing.Optional[bool] = OMIT,
        workspace_role: typing.Optional[BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdateWorkspaceMemberResponseModel:
        """
        Updates attributes of a workspace member. Apart from the email identifier, all parameters will remain unchanged unless specified. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        email : str
            Email of the target user.

        is_locked : typing.Optional[bool]
            Whether to lock or unlock the user account.

        workspace_role : typing.Optional[BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole]
            Role dictating permissions in the workspace.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdateWorkspaceMemberResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.update_member(
            email="email",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/workspace/members",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "email": email,
                "is_locked": is_locked,
                "workspace_role": workspace_role,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    UpdateWorkspaceMemberResponseModel,
                    construct_type(
                        type_=UpdateWorkspaceMemberResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_resource(
        self,
        resource_id: str,
        *,
        resource_type: WorkspaceResourceType,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResourceMetadataResponseModel:
        """
        Gets the metadata of a resource by ID.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResourceMetadataResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.get_resource(
            resource_id="resource_id",
            resource_type="voice",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/workspace/resources/{jsonable_encoder(resource_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "resource_type": resource_type,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ResourceMetadataResponseModel,
                    construct_type(
                        type_=ResourceMetadataResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def share_workspace_resource(
        self,
        resource_id: str,
        *,
        role: BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
        resource_type: WorkspaceResourceType,
        user_email: typing.Optional[str] = OMIT,
        group_id: typing.Optional[str] = OMIT,
        workspace_api_key_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Optional[typing.Any]:
        """
        Grants a role on a workspace resource to a user or a group. It overrides any existing role this user/group/workspace api key has on the resource. To target a user, pass only the user email. The user must be in your workspace. To target a group, pass only the group id. To target a workspace api key, pass the api key id. You must have admin access to the resource to share it.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        role : BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole
            Role to update the target principal with.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        user_email : typing.Optional[str]
            The email of the user

        group_id : typing.Optional[str]
            The ID of the target group. To target the permissions principals have by default on this resource, use the value 'default'.

        workspace_api_key_id : typing.Optional[str]
            The ID of the target workspace API key. This isn't the same as the key itself that would you pass in the header for authentication. Workspace admins can find this in the workspace settings UI.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.share_workspace_resource(
            resource_id="resource_id",
            role="admin",
            resource_type="voice",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/workspace/resources/{jsonable_encoder(resource_id)}/share",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "role": role,
                "resource_type": resource_type,
                "user_email": user_email,
                "group_id": group_id,
                "workspace_api_key_id": workspace_api_key_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.Optional[typing.Any],
                    construct_type(
                        type_=typing.Optional[typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def unshare_workspace_resource(
        self,
        resource_id: str,
        *,
        resource_type: WorkspaceResourceType,
        user_email: typing.Optional[str] = OMIT,
        group_id: typing.Optional[str] = OMIT,
        workspace_api_key_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Optional[typing.Any]:
        """
        Removes any existing role on a workspace resource from a user or a group. To target a user, pass only the user email. The user must be in your workspace. To target a group, pass only the group id. To target a workspace api key, pass the api key id. You must have admin access to the resource to unshare it. You cannot remove permissions from the user who created the resource.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        user_email : typing.Optional[str]
            The email of the user

        group_id : typing.Optional[str]
            The ID of the target group. To target the permissions principals have by default on this resource, use the value 'default'.

        workspace_api_key_id : typing.Optional[str]
            The ID of the target workspace API key. This isn't the same as the key itself that would you pass in the header for authentication. Workspace admins can find this in the workspace settings UI.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.unshare_workspace_resource(
            resource_id="resource_id",
            resource_type="voice",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/workspace/resources/{jsonable_encoder(resource_id)}/unshare",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "resource_type": resource_type,
                "user_email": user_email,
                "group_id": group_id,
                "workspace_api_key_id": workspace_api_key_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.Optional[typing.Any],
                    construct_type(
                        type_=typing.Optional[typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncWorkspaceClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def search_user_groups(
        self, *, name: str, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[WorkspaceGroupByNameResponseModel]:
        """
        Searches for user groups in the workspace. Multiple or no groups may be returned.

        Parameters
        ----------
        name : str
            Name of the target group.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[WorkspaceGroupByNameResponseModel]
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.search_user_groups(
                name="name",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/workspace/groups/search",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "name": name,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[WorkspaceGroupByNameResponseModel],
                    construct_type(
                        type_=typing.List[WorkspaceGroupByNameResponseModel],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_member_from_user_group(
        self,
        group_id: str,
        *,
        email: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DeleteWorkspaceGroupMemberResponseModel:
        """
        Removes a member from the specified group. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        group_id : str
            The ID of the target group.

        email : str
            The email of the target workspace member.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteWorkspaceGroupMemberResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.delete_member_from_user_group(
                group_id="group_id",
                email="email",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/workspace/groups/{jsonable_encoder(group_id)}/members/remove",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "email": email,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DeleteWorkspaceGroupMemberResponseModel,
                    construct_type(
                        type_=DeleteWorkspaceGroupMemberResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def add_member_to_user_group(
        self,
        group_id: str,
        *,
        email: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddWorkspaceGroupMemberResponseModel:
        """
        Adds a member of your workspace to the specified group. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        group_id : str
            The ID of the target group.

        email : str
            The email of the target workspace member.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddWorkspaceGroupMemberResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.add_member_to_user_group(
                group_id="group_id",
                email="email",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/workspace/groups/{jsonable_encoder(group_id)}/members",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "email": email,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddWorkspaceGroupMemberResponseModel,
                    construct_type(
                        type_=AddWorkspaceGroupMemberResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def invite_user(
        self,
        *,
        email: str,
        group_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddWorkspaceInviteResponseModel:
        """
        Sends an email invitation to join your workspace to the provided email. If the user doesn't have an account they will be prompted to create one. If the user accepts this invite they will be added as a user to your workspace and your subscription using one of your seats. This endpoint may only be called by workspace administrators. If the user is already in the workspace a 400 error will be returned.

        Parameters
        ----------
        email : str
            The email of the customer

        group_ids : typing.Optional[typing.Sequence[str]]
            The group ids of the user

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddWorkspaceInviteResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.invite_user(
                email="john.doe@testmail.com",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/workspace/invites/add",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "email": email,
                "group_ids": group_ids,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddWorkspaceInviteResponseModel,
                    construct_type(
                        type_=AddWorkspaceInviteResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def invite_multiple_users(
        self,
        *,
        emails: typing.Sequence[str],
        group_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddWorkspaceInviteResponseModel:
        """
        Sends email invitations to join your workspace to the provided emails. Requires all email addresses to be part of a verified domain. If the users don't have an account they will be prompted to create one. If the users accept these invites they will be added as users to your workspace and your subscription using one of your seats. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        emails : typing.Sequence[str]
            The email of the customer

        group_ids : typing.Optional[typing.Sequence[str]]
            The group ids of the user

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddWorkspaceInviteResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.invite_multiple_users(
                emails=["emails"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/workspace/invites/add-bulk",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "emails": emails,
                "group_ids": group_ids,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddWorkspaceInviteResponseModel,
                    construct_type(
                        type_=AddWorkspaceInviteResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_existing_invitation(
        self, *, email: str, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteWorkspaceInviteResponseModel:
        """
        Invalidates an existing email invitation. The invitation will still show up in the inbox it has been delivered to, but activating it to join the workspace won't work. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        email : str
            The email of the customer

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteWorkspaceInviteResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.delete_existing_invitation(
                email="john.doe@testmail.com",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/workspace/invites",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            json={
                "email": email,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DeleteWorkspaceInviteResponseModel,
                    construct_type(
                        type_=DeleteWorkspaceInviteResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_member(
        self,
        *,
        email: str,
        is_locked: typing.Optional[bool] = OMIT,
        workspace_role: typing.Optional[BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdateWorkspaceMemberResponseModel:
        """
        Updates attributes of a workspace member. Apart from the email identifier, all parameters will remain unchanged unless specified. This endpoint may only be called by workspace administrators.

        Parameters
        ----------
        email : str
            Email of the target user.

        is_locked : typing.Optional[bool]
            Whether to lock or unlock the user account.

        workspace_role : typing.Optional[BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole]
            Role dictating permissions in the workspace.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdateWorkspaceMemberResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.update_member(
                email="email",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/workspace/members",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "email": email,
                "is_locked": is_locked,
                "workspace_role": workspace_role,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    UpdateWorkspaceMemberResponseModel,
                    construct_type(
                        type_=UpdateWorkspaceMemberResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_resource(
        self,
        resource_id: str,
        *,
        resource_type: WorkspaceResourceType,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResourceMetadataResponseModel:
        """
        Gets the metadata of a resource by ID.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResourceMetadataResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.get_resource(
                resource_id="resource_id",
                resource_type="voice",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/workspace/resources/{jsonable_encoder(resource_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "resource_type": resource_type,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ResourceMetadataResponseModel,
                    construct_type(
                        type_=ResourceMetadataResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def share_workspace_resource(
        self,
        resource_id: str,
        *,
        role: BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
        resource_type: WorkspaceResourceType,
        user_email: typing.Optional[str] = OMIT,
        group_id: typing.Optional[str] = OMIT,
        workspace_api_key_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Optional[typing.Any]:
        """
        Grants a role on a workspace resource to a user or a group. It overrides any existing role this user/group/workspace api key has on the resource. To target a user, pass only the user email. The user must be in your workspace. To target a group, pass only the group id. To target a workspace api key, pass the api key id. You must have admin access to the resource to share it.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        role : BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole
            Role to update the target principal with.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        user_email : typing.Optional[str]
            The email of the user

        group_id : typing.Optional[str]
            The ID of the target group. To target the permissions principals have by default on this resource, use the value 'default'.

        workspace_api_key_id : typing.Optional[str]
            The ID of the target workspace API key. This isn't the same as the key itself that would you pass in the header for authentication. Workspace admins can find this in the workspace settings UI.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.share_workspace_resource(
                resource_id="resource_id",
                role="admin",
                resource_type="voice",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/workspace/resources/{jsonable_encoder(resource_id)}/share",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "role": role,
                "resource_type": resource_type,
                "user_email": user_email,
                "group_id": group_id,
                "workspace_api_key_id": workspace_api_key_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.Optional[typing.Any],
                    construct_type(
                        type_=typing.Optional[typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def unshare_workspace_resource(
        self,
        resource_id: str,
        *,
        resource_type: WorkspaceResourceType,
        user_email: typing.Optional[str] = OMIT,
        group_id: typing.Optional[str] = OMIT,
        workspace_api_key_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Optional[typing.Any]:
        """
        Removes any existing role on a workspace resource from a user or a group. To target a user, pass only the user email. The user must be in your workspace. To target a group, pass only the group id. To target a workspace api key, pass the api key id. You must have admin access to the resource to unshare it. You cannot remove permissions from the user who created the resource.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        user_email : typing.Optional[str]
            The email of the user

        group_id : typing.Optional[str]
            The ID of the target group. To target the permissions principals have by default on this resource, use the value 'default'.

        workspace_api_key_id : typing.Optional[str]
            The ID of the target workspace API key. This isn't the same as the key itself that would you pass in the header for authentication. Workspace admins can find this in the workspace settings UI.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.unshare_workspace_resource(
                resource_id="resource_id",
                resource_type="voice",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/workspace/resources/{jsonable_encoder(resource_id)}/unshare",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "resource_type": resource_type,
                "user_email": user_email,
                "group_id": group_id,
                "workspace_api_key_id": workspace_api_key_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.Optional[typing.Any],
                    construct_type(
                        type_=typing.Optional[typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .safety_rule import SafetyRule
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class SafetyEvaluation(UncheckedBaseModel):
    """
    Safety evaluation of the agent. Prompt and first message is taken into account.
    The unsafe reason is provided from the evaluation
    """

    is_unsafe: typing.Optional[bool] = None
    llm_reason: typing.Optional[str] = None
    safety_prompt_version: typing.Optional[int] = None
    matched_rule_id: typing.Optional[typing.List[SafetyRule]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
import typing_extensions
from ..core.unchecked_base_model import UnionMetadata


class WidgetConfigAvatar_Orb(UncheckedBaseModel):
    """
    The avatar of the widget
    """

    type: typing.Literal["orb"] = "orb"
    color_1: typing.Optional[str] = None
    color_2: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WidgetConfigAvatar_Url(UncheckedBaseModel):
    """
    The avatar of the widget
    """

    type: typing.Literal["url"] = "url"
    custom_url: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WidgetConfigAvatar_Image(UncheckedBaseModel):
    """
    The avatar of the widget
    """

    type: typing.Literal["image"] = "image"
    url: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


WidgetConfigAvatar = typing_extensions.Annotated[
    typing.Union[WidgetConfigAvatar_Orb, WidgetConfigAvatar_Url, WidgetConfigAvatar_Image],
    UnionMetadata(discriminant="type"),
]



# This file was auto-generated by Fern from our API Definition.

import typing

TtsConversationalModel = typing.Union[
    typing.Literal["eleven_turbo_v2", "eleven_turbo_v2_5", "eleven_flash_v2", "eleven_flash_v2_5"],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .conversation_history_evaluation_criteria_result_common_model import (
    ConversationHistoryEvaluationCriteriaResultCommonModel,
)
from .data_collection_result_common_model import DataCollectionResultCommonModel
from .evaluation_success_result import EvaluationSuccessResult
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ConversationHistoryAnalysisCommonModel(UncheckedBaseModel):
    evaluation_criteria_results: typing.Optional[
        typing.Dict[str, ConversationHistoryEvaluationCriteriaResultCommonModel]
    ] = None
    data_collection_results: typing.Optional[typing.Dict[str, DataCollectionResultCommonModel]] = None
    call_successful: EvaluationSuccessResult
    transcript_summary: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ProjectsAddRequestTargetAudience = typing.Union[
    typing.Literal["children", "young adult", "adult", "all ages"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .history_alignment_response_model import HistoryAlignmentResponseModel
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class HistoryAlignmentsResponseModel(UncheckedBaseModel):
    alignment: HistoryAlignmentResponseModel = pydantic.Field()
    """
    The alignment of the text.
    """

    normalized_alignment: HistoryAlignmentResponseModel = pydantic.Field()
    """
    The normalized alignment of the text.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .get_pronunciation_dictionary_metadata_response import (
    GetPronunciationDictionaryMetadataResponse,
)
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class GetPronunciationDictionariesMetadataResponseModel(UncheckedBaseModel):
    pronunciation_dictionaries: typing.List[GetPronunciationDictionaryMetadataResponse] = pydantic.Field()
    """
    A list of pronunciation dictionaries and their metadata.
    """

    next_cursor: typing.Optional[str] = pydantic.Field(default=None)
    """
    The next cursor to use for pagination.
    """

    has_more: bool = pydantic.Field()
    """
    Whether there are more pronunciation dictionaries to fetch.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

SafetyRule = typing.Union[
    typing.Literal[
        "sexual_minors",
        "forget_moderation",
        "extremism",
        "scam_fraud",
        "political",
        "self_harm",
        "illegal_distribution_medical",
        "sexual_adults",
        "unknown",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from .dubbing_get_transcript_for_dub_request_format_type import DubbingGetTranscriptForDubRequestFormatType

__all__ = ["DubbingGetTranscriptForDubRequestFormatType"]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .conversation_config_client_override_input import (
    ConversationConfigClientOverrideInput,
)
from .conversation_initiation_client_data_request_input_dynamic_variables_value import (
    ConversationInitiationClientDataRequestInputDynamicVariablesValue,
)
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ConversationInitiationClientDataRequestInput(UncheckedBaseModel):
    conversation_config_override: typing.Optional[ConversationConfigClientOverrideInput] = None
    custom_llm_extra_body: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    dynamic_variables: typing.Optional[
        typing.Dict[
            str,
            typing.Optional[ConversationInitiationClientDataRequestInputDynamicVariablesValue],
        ]
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .get_conversation_response_model_status import GetConversationResponseModelStatus
import typing
from .conversation_history_transcript_common_model import (
    ConversationHistoryTranscriptCommonModel,
)
from .conversation_history_metadata_common_model import (
    ConversationHistoryMetadataCommonModel,
)
from .conversation_history_analysis_common_model import (
    ConversationHistoryAnalysisCommonModel,
)
from .conversation_initiation_client_data_request_output import (
    ConversationInitiationClientDataRequestOutput,
)
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetConversationResponseModel(UncheckedBaseModel):
    agent_id: str
    conversation_id: str
    status: GetConversationResponseModelStatus
    transcript: typing.List[ConversationHistoryTranscriptCommonModel]
    metadata: ConversationHistoryMetadataCommonModel
    analysis: typing.Optional[ConversationHistoryAnalysisCommonModel] = None
    conversation_initiation_client_data: typing.Optional[ConversationInitiationClientDataRequestOutput] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class AddPronunciationDictionaryResponseModel(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    The ID of the created pronunciation dictionary.
    """

    name: str = pydantic.Field()
    """
    The name of the created pronunciation dictionary.
    """

    created_by: str = pydantic.Field()
    """
    The user ID of the creator of the pronunciation dictionary.
    """

    creation_time_unix: int = pydantic.Field()
    """
    The creation time of the pronunciation dictionary in Unix timestamp.
    """

    version_id: str = pydantic.Field()
    """
    The ID of the created pronunciation dictionary version.
    """

    version_rules_num: int = pydantic.Field()
    """
    The number of rules in the version of the pronunciation dictionary.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the pronunciation dictionary.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .speech_to_text_convert_request_timestamps_granularity import SpeechToTextConvertRequestTimestampsGranularity

__all__ = ["SpeechToTextConvertRequestTimestampsGranularity"]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .conv_ai_stored_secret_dependencies_tools_item import (
    ConvAiStoredSecretDependenciesToolsItem,
)
from .conv_ai_stored_secret_dependencies_agent_tools_item import (
    ConvAiStoredSecretDependenciesAgentToolsItem,
)
from .secret_dependency_type import SecretDependencyType
from .dependent_phone_number_identifier import DependentPhoneNumberIdentifier
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ConvAiStoredSecretDependencies(UncheckedBaseModel):
    tools: typing.List[ConvAiStoredSecretDependenciesToolsItem]
    agent_tools: typing.List[ConvAiStoredSecretDependenciesAgentToolsItem]
    others: typing.List[SecretDependencyType]
    phone_numbers: typing.Optional[typing.List[DependentPhoneNumberIdentifier]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .accent import Accent
from .add_agent_secret_response_model import AddAgentSecretResponseModel
from .add_chapter_response_model import AddChapterResponseModel
from .add_knowledge_base_response_model import AddKnowledgeBaseResponseModel
from .add_project_response_model import AddProjectResponseModel
from .add_pronunciation_dictionary_response_model import AddPronunciationDictionaryResponseModel
from .add_pronunciation_dictionary_rules_response_model import AddPronunciationDictionaryRulesResponseModel
from .add_sharing_voice_request import AddSharingVoiceRequest
from .add_voice_ivc_response_model import AddVoiceIvcResponseModel
from .add_voice_response_model import AddVoiceResponseModel
from .add_workspace_group_member_response_model import AddWorkspaceGroupMemberResponseModel
from .add_workspace_invite_response_model import AddWorkspaceInviteResponseModel
from .age import Age
from .agent_ban import AgentBan
from .agent_call_limits import AgentCallLimits
from .agent_config_api_model_input import AgentConfigApiModelInput
from .agent_config_api_model_output import AgentConfigApiModelOutput
from .agent_config_override import AgentConfigOverride
from .agent_config_override_config import AgentConfigOverrideConfig
from .agent_metadata_response_model import AgentMetadataResponseModel
from .agent_platform_settings_request_model import AgentPlatformSettingsRequestModel
from .agent_platform_settings_response_model import AgentPlatformSettingsResponseModel
from .agent_summary_response_model import AgentSummaryResponseModel
from .agent_workspace_overrides_input import AgentWorkspaceOverridesInput
from .agent_workspace_overrides_output import AgentWorkspaceOverridesOutput
from .allowlist_item import AllowlistItem
from .array_json_schema_property_input import ArrayJsonSchemaPropertyInput
from .array_json_schema_property_input_items import ArrayJsonSchemaPropertyInputItems
from .array_json_schema_property_output import ArrayJsonSchemaPropertyOutput
from .array_json_schema_property_output_items import ArrayJsonSchemaPropertyOutputItems
from .asr_conversational_config import AsrConversationalConfig
from .asr_input_format import AsrInputFormat
from .asr_provider import AsrProvider
from .asr_quality import AsrQuality
from .audio_native_create_project_response_model import AudioNativeCreateProjectResponseModel
from .audio_native_edit_content_response_model import AudioNativeEditContentResponseModel
from .audio_native_project_settings_response_model import AudioNativeProjectSettingsResponseModel
from .audio_output import AudioOutput
from .audio_with_timestamps_response_model import AudioWithTimestampsResponseModel
from .auth_settings import AuthSettings
from .authorization_method import AuthorizationMethod
from .ban_reason_type import BanReasonType
from .body_add_to_knowledge_base_v_1_convai_add_to_knowledge_base_post import (
    BodyAddToKnowledgeBaseV1ConvaiAddToKnowledgeBasePost,
)
from .body_add_to_knowledge_base_v_1_convai_agents_agent_id_add_to_knowledge_base_post import (
    BodyAddToKnowledgeBaseV1ConvaiAgentsAgentIdAddToKnowledgeBasePost,
)
from .breakdown_types import BreakdownTypes
from .chapter_content_block_extendable_node_response_model import ChapterContentBlockExtendableNodeResponseModel
from .chapter_content_block_input_model import ChapterContentBlockInputModel
from .chapter_content_block_response_model import ChapterContentBlockResponseModel
from .chapter_content_block_response_model_nodes_item import (
    ChapterContentBlockResponseModelNodesItem,
    ChapterContentBlockResponseModelNodesItem_Other,
    ChapterContentBlockResponseModelNodesItem_TtsNode,
)
from .chapter_content_block_tts_node_response_model import ChapterContentBlockTtsNodeResponseModel
from .chapter_content_input_model import ChapterContentInputModel
from .chapter_content_paragraph_tts_node_input_model import ChapterContentParagraphTtsNodeInputModel
from .chapter_content_response_model import ChapterContentResponseModel
from .chapter_response import ChapterResponse
from .chapter_snapshot_extended_response_model import ChapterSnapshotExtendedResponseModel
from .chapter_snapshot_response import ChapterSnapshotResponse
from .chapter_snapshots_response import ChapterSnapshotsResponse
from .chapter_state import ChapterState
from .chapter_statistics_response import ChapterStatisticsResponse
from .chapter_with_content_response_model import ChapterWithContentResponseModel
from .chapter_with_content_response_model_state import ChapterWithContentResponseModelState
from .character_alignment_model import CharacterAlignmentModel
from .character_alignment_response_model import CharacterAlignmentResponseModel
from .client_event import ClientEvent
from .client_tool_config_input import ClientToolConfigInput
from .client_tool_config_output import ClientToolConfigOutput
from .close_connection import CloseConnection
from .conv_ai_secret_locator import ConvAiSecretLocator
from .conv_ai_stored_secret_dependencies import ConvAiStoredSecretDependencies
from .conv_ai_stored_secret_dependencies_agent_tools_item import (
    ConvAiStoredSecretDependenciesAgentToolsItem,
    ConvAiStoredSecretDependenciesAgentToolsItem_Available,
    ConvAiStoredSecretDependenciesAgentToolsItem_Unknown,
)
from .conv_ai_stored_secret_dependencies_tools_item import (
    ConvAiStoredSecretDependenciesToolsItem,
    ConvAiStoredSecretDependenciesToolsItem_Available,
    ConvAiStoredSecretDependenciesToolsItem_Unknown,
)
from .conv_ai_webhooks import ConvAiWebhooks
from .conv_ai_workspace_stored_secret_config import ConvAiWorkspaceStoredSecretConfig
from .conversation_charging_common_model import ConversationChargingCommonModel
from .conversation_config import ConversationConfig
from .conversation_config_client_override_config_input import ConversationConfigClientOverrideConfigInput
from .conversation_config_client_override_config_output import ConversationConfigClientOverrideConfigOutput
from .conversation_config_client_override_input import ConversationConfigClientOverrideInput
from .conversation_config_client_override_output import ConversationConfigClientOverrideOutput
from .conversation_deletion_settings import ConversationDeletionSettings
from .conversation_history_analysis_common_model import ConversationHistoryAnalysisCommonModel
from .conversation_history_evaluation_criteria_result_common_model import (
    ConversationHistoryEvaluationCriteriaResultCommonModel,
)
from .conversation_history_feedback_common_model import ConversationHistoryFeedbackCommonModel
from .conversation_history_metadata_common_model import ConversationHistoryMetadataCommonModel
from .conversation_history_metadata_common_model_phone_call import (
    ConversationHistoryMetadataCommonModelPhoneCall,
    ConversationHistoryMetadataCommonModelPhoneCall_Twilio,
)
from .conversation_history_transcript_common_model import ConversationHistoryTranscriptCommonModel
from .conversation_history_transcript_common_model_role import ConversationHistoryTranscriptCommonModelRole
from .conversation_history_transcript_tool_call_common_model import ConversationHistoryTranscriptToolCallCommonModel
from .conversation_history_transcript_tool_result_common_model import ConversationHistoryTranscriptToolResultCommonModel
from .conversation_history_twilio_phone_call_model import ConversationHistoryTwilioPhoneCallModel
from .conversation_history_twilio_phone_call_model_direction import ConversationHistoryTwilioPhoneCallModelDirection
from .conversation_initiation_client_data_config_input import ConversationInitiationClientDataConfigInput
from .conversation_initiation_client_data_config_output import ConversationInitiationClientDataConfigOutput
from .conversation_initiation_client_data_request_input import ConversationInitiationClientDataRequestInput
from .conversation_initiation_client_data_request_input_dynamic_variables_value import (
    ConversationInitiationClientDataRequestInputDynamicVariablesValue,
)
from .conversation_initiation_client_data_request_output import ConversationInitiationClientDataRequestOutput
from .conversation_initiation_client_data_request_output_dynamic_variables_value import (
    ConversationInitiationClientDataRequestOutputDynamicVariablesValue,
)
from .conversation_initiation_client_data_webhook import ConversationInitiationClientDataWebhook
from .conversation_initiation_client_data_webhook_request_headers_value import (
    ConversationInitiationClientDataWebhookRequestHeadersValue,
)
from .conversation_signed_url_response_model import ConversationSignedUrlResponseModel
from .conversation_summary_response_model import ConversationSummaryResponseModel
from .conversation_summary_response_model_status import ConversationSummaryResponseModelStatus
from .conversation_token_db_model import ConversationTokenDbModel
from .conversation_token_purpose import ConversationTokenPurpose
from .conversation_turn_metrics import ConversationTurnMetrics
from .conversational_config_api_model_input import ConversationalConfigApiModelInput
from .conversational_config_api_model_output import ConversationalConfigApiModelOutput
from .convert_chapter_response_model import ConvertChapterResponseModel
from .convert_project_response_model import ConvertProjectResponseModel
from .create_agent_response_model import CreateAgentResponseModel
from .create_audio_native_project_request import CreateAudioNativeProjectRequest
from .create_phone_number_response_model import CreatePhoneNumberResponseModel
from .create_pronunciation_dictionary_response_model import CreatePronunciationDictionaryResponseModel
from .create_sip_trunk_phone_number_request import CreateSipTrunkPhoneNumberRequest
from .create_twilio_phone_number_request import CreateTwilioPhoneNumberRequest
from .currency import Currency
from .custom_llm import CustomLlm
from .data_collection_result_common_model import DataCollectionResultCommonModel
from .delete_chapter_response_model import DeleteChapterResponseModel
from .delete_dubbing_response_model import DeleteDubbingResponseModel
from .delete_history_item_response import DeleteHistoryItemResponse
from .delete_project_response_model import DeleteProjectResponseModel
from .delete_sample_response_model import DeleteSampleResponseModel
from .delete_voice_response_model import DeleteVoiceResponseModel
from .delete_workspace_group_member_response_model import DeleteWorkspaceGroupMemberResponseModel
from .delete_workspace_invite_response_model import DeleteWorkspaceInviteResponseModel
from .dependent_available_agent_identifier import DependentAvailableAgentIdentifier
from .dependent_available_agent_identifier_access_level import DependentAvailableAgentIdentifierAccessLevel
from .dependent_available_agent_tool_identifier import DependentAvailableAgentToolIdentifier
from .dependent_available_agent_tool_identifier_access_level import DependentAvailableAgentToolIdentifierAccessLevel
from .dependent_available_tool_identifier import DependentAvailableToolIdentifier
from .dependent_available_tool_identifier_access_level import DependentAvailableToolIdentifierAccessLevel
from .dependent_phone_number_identifier import DependentPhoneNumberIdentifier
from .dependent_unknown_agent_identifier import DependentUnknownAgentIdentifier
from .dependent_unknown_agent_tool_identifier import DependentUnknownAgentToolIdentifier
from .dependent_unknown_tool_identifier import DependentUnknownToolIdentifier
from .do_dubbing_response import DoDubbingResponse
from .document_usage_mode_enum import DocumentUsageModeEnum
from .dubbed_segment import DubbedSegment
from .dubbing_media_metadata import DubbingMediaMetadata
from .dubbing_media_reference import DubbingMediaReference
from .dubbing_metadata_response import DubbingMetadataResponse
from .dubbing_resource import DubbingResource
from .dynamic_variables_config import DynamicVariablesConfig
from .dynamic_variables_config_dynamic_variable_placeholders_value import (
    DynamicVariablesConfigDynamicVariablePlaceholdersValue,
)
from .edit_chapter_response_model import EditChapterResponseModel
from .edit_project_response_model import EditProjectResponseModel
from .edit_voice_response_model import EditVoiceResponseModel
from .edit_voice_settings_response_model import EditVoiceSettingsResponseModel
from .embed_variant import EmbedVariant
from .embedding_model_enum import EmbeddingModelEnum
from .evaluation_settings import EvaluationSettings
from .evaluation_success_result import EvaluationSuccessResult
from .extended_subscription_response_model_billing_period import ExtendedSubscriptionResponseModelBillingPeriod
from .extended_subscription_response_model_character_refresh_period import (
    ExtendedSubscriptionResponseModelCharacterRefreshPeriod,
)
from .extended_subscription_response_model_currency import ExtendedSubscriptionResponseModelCurrency
from .feedback_item import FeedbackItem
from .fine_tuning_response import FineTuningResponse
from .fine_tuning_response_model_state_value import FineTuningResponseModelStateValue
from .gender import Gender
from .generation_config import GenerationConfig
from .get_agent_embed_response_model import GetAgentEmbedResponseModel
from .get_agent_link_response_model import GetAgentLinkResponseModel
from .get_agent_response_model import GetAgentResponseModel
from .get_agents_page_response_model import GetAgentsPageResponseModel
from .get_audio_native_project_settings_response_model import GetAudioNativeProjectSettingsResponseModel
from .get_chapters_response import GetChaptersResponse
from .get_conv_ai_settings_response_model import GetConvAiSettingsResponseModel
from .get_conversation_response_model import GetConversationResponseModel
from .get_conversation_response_model_status import GetConversationResponseModelStatus
from .get_conversations_page_response_model import GetConversationsPageResponseModel
from .get_knowledge_base_dependent_agents_response_model import GetKnowledgeBaseDependentAgentsResponseModel
from .get_knowledge_base_dependent_agents_response_model_agents_item import (
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown,
)
from .get_knowledge_base_file_response_model import GetKnowledgeBaseFileResponseModel
from .get_knowledge_base_list_response_model import GetKnowledgeBaseListResponseModel
from .get_knowledge_base_list_response_model_documents_item import (
    GetKnowledgeBaseListResponseModelDocumentsItem,
    GetKnowledgeBaseListResponseModelDocumentsItem_File,
    GetKnowledgeBaseListResponseModelDocumentsItem_Url,
)
from .get_knowledge_base_summary_file_response_model import GetKnowledgeBaseSummaryFileResponseModel
from .get_knowledge_base_summary_file_response_model_dependent_agents_item import (
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown,
)
from .get_knowledge_base_summary_url_response_model import GetKnowledgeBaseSummaryUrlResponseModel
from .get_knowledge_base_summary_url_response_model_dependent_agents_item import (
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown,
)
from .get_knowledge_base_url_response_model import GetKnowledgeBaseUrlResponseModel
from .get_library_voices_response import GetLibraryVoicesResponse
from .get_phone_number_response_model import GetPhoneNumberResponseModel
from .get_projects_response import GetProjectsResponse
from .get_pronunciation_dictionaries_metadata_response_model import GetPronunciationDictionariesMetadataResponseModel
from .get_pronunciation_dictionary_metadata_response import GetPronunciationDictionaryMetadataResponse
from .get_speech_history_response import GetSpeechHistoryResponse
from .get_voices_response import GetVoicesResponse
from .get_voices_v_2_response_model import GetVoicesV2ResponseModel
from .get_workspace_secrets_response_model import GetWorkspaceSecretsResponseModel
from .history_alignment_response_model import HistoryAlignmentResponseModel
from .history_alignments_response_model import HistoryAlignmentsResponseModel
from .history_item import HistoryItem
from .http_validation_error import HttpValidationError
from .image_avatar import ImageAvatar
from .initialize_connection import InitializeConnection
from .invoice import Invoice
from .knowledge_base_document_chunk_response_model import KnowledgeBaseDocumentChunkResponseModel
from .knowledge_base_document_metadata_response_model import KnowledgeBaseDocumentMetadataResponseModel
from .knowledge_base_locator import KnowledgeBaseLocator
from .knowledge_base_locator_type import KnowledgeBaseLocatorType
from .language_added_response import LanguageAddedResponse
from .language_preset_input import LanguagePresetInput
from .language_preset_output import LanguagePresetOutput
from .language_preset_translation import LanguagePresetTranslation
from .language_response import LanguageResponse
from .library_voice_response import LibraryVoiceResponse
from .library_voice_response_model_category import LibraryVoiceResponseModelCategory
from .literal_json_schema_property import LiteralJsonSchemaProperty
from .literal_json_schema_property_constant_value import LiteralJsonSchemaPropertyConstantValue
from .literal_json_schema_property_type import LiteralJsonSchemaPropertyType
from .llm import Llm
from .manual_verification_file_response import ManualVerificationFileResponse
from .manual_verification_response import ManualVerificationResponse
from .metric_record import MetricRecord
from .model import Model
from .model_rates_response_model import ModelRatesResponseModel
from .model_response_model_concurrency_group import ModelResponseModelConcurrencyGroup
from .moderation_status_response_model import ModerationStatusResponseModel
from .moderation_status_response_model_safety_status import ModerationStatusResponseModelSafetyStatus
from .moderation_status_response_model_warning_status import ModerationStatusResponseModelWarningStatus
from .normalized_alignment import NormalizedAlignment
from .object_json_schema_property_input import ObjectJsonSchemaPropertyInput
from .object_json_schema_property_input_properties_value import ObjectJsonSchemaPropertyInputPropertiesValue
from .object_json_schema_property_output import ObjectJsonSchemaPropertyOutput
from .object_json_schema_property_output_properties_value import ObjectJsonSchemaPropertyOutputPropertiesValue
from .orb_avatar import OrbAvatar
from .output_format import OutputFormat
from .phone_number_agent_info import PhoneNumberAgentInfo
from .podcast_bulletin_mode import PodcastBulletinMode
from .podcast_bulletin_mode_data import PodcastBulletinModeData
from .podcast_conversation_mode import PodcastConversationMode
from .podcast_conversation_mode_data import PodcastConversationModeData
from .podcast_project_response_model import PodcastProjectResponseModel
from .podcast_text_source import PodcastTextSource
from .podcast_url_source import PodcastUrlSource
from .post_agent_avatar_response_model import PostAgentAvatarResponseModel
from .post_workspace_secret_response_model import PostWorkspaceSecretResponseModel
from .privacy_config import PrivacyConfig
from .profile_page_response_model import ProfilePageResponseModel
from .project_creation_meta_response_model import ProjectCreationMetaResponseModel
from .project_creation_meta_response_model_status import ProjectCreationMetaResponseModelStatus
from .project_creation_meta_response_model_type import ProjectCreationMetaResponseModelType
from .project_extended_response_model import ProjectExtendedResponseModel
from .project_extended_response_model_access_level import ProjectExtendedResponseModelAccessLevel
from .project_extended_response_model_apply_text_normalization import ProjectExtendedResponseModelApplyTextNormalization
from .project_extended_response_model_fiction import ProjectExtendedResponseModelFiction
from .project_extended_response_model_quality_preset import ProjectExtendedResponseModelQualityPreset
from .project_extended_response_model_source_type import ProjectExtendedResponseModelSourceType
from .project_extended_response_model_target_audience import ProjectExtendedResponseModelTargetAudience
from .project_response import ProjectResponse
from .project_response_model_access_level import ProjectResponseModelAccessLevel
from .project_response_model_fiction import ProjectResponseModelFiction
from .project_response_model_source_type import ProjectResponseModelSourceType
from .project_response_model_target_audience import ProjectResponseModelTargetAudience
from .project_snapshot_extended_response_model import ProjectSnapshotExtendedResponseModel
from .project_snapshot_response import ProjectSnapshotResponse
from .project_snapshots_response import ProjectSnapshotsResponse
from .project_state import ProjectState
from .prompt_agent_input import PromptAgentInput
from .prompt_agent_input_tools_item import (
    PromptAgentInputToolsItem,
    PromptAgentInputToolsItem_Client,
    PromptAgentInputToolsItem_System,
    PromptAgentInputToolsItem_Webhook,
)
from .prompt_agent_output import PromptAgentOutput
from .prompt_agent_output_tools_item import (
    PromptAgentOutputToolsItem,
    PromptAgentOutputToolsItem_Client,
    PromptAgentOutputToolsItem_System,
    PromptAgentOutputToolsItem_Webhook,
)
from .prompt_agent_override import PromptAgentOverride
from .prompt_agent_override_config import PromptAgentOverrideConfig
from .prompt_evaluation_criteria import PromptEvaluationCriteria
from .pronunciation_dictionary_alias_rule_request_model import PronunciationDictionaryAliasRuleRequestModel
from .pronunciation_dictionary_phoneme_rule_request_model import PronunciationDictionaryPhonemeRuleRequestModel
from .pronunciation_dictionary_version_locator import PronunciationDictionaryVersionLocator
from .pronunciation_dictionary_version_response_model import PronunciationDictionaryVersionResponseModel
from .pydantic_pronunciation_dictionary_version_locator import PydanticPronunciationDictionaryVersionLocator
from .query_params_json_schema import QueryParamsJsonSchema
from .rag_chunk_metadata import RagChunkMetadata
from .rag_config import RagConfig
from .rag_index_response_model import RagIndexResponseModel
from .rag_index_status import RagIndexStatus
from .rag_retrieval_info import RagRetrievalInfo
from .reader_resource_response_model import ReaderResourceResponseModel
from .reader_resource_response_model_resource_type import ReaderResourceResponseModelResourceType
from .realtime_voice_settings import RealtimeVoiceSettings
from .recording_response import RecordingResponse
from .remove_pronunciation_dictionary_rules_response_model import RemovePronunciationDictionaryRulesResponseModel
from .resource_access_info import ResourceAccessInfo
from .resource_access_info_role import ResourceAccessInfoRole
from .resource_metadata_response_model import ResourceMetadataResponseModel
from .review_status import ReviewStatus
from .safety_common_model import SafetyCommonModel
from .safety_evaluation import SafetyEvaluation
from .safety_response_model import SafetyResponseModel
from .safety_rule import SafetyRule
from .secret_dependency_type import SecretDependencyType
from .segment_create_response import SegmentCreateResponse
from .segment_delete_response import SegmentDeleteResponse
from .segment_dub_response import SegmentDubResponse
from .segment_transcription_response import SegmentTranscriptionResponse
from .segment_translation_response import SegmentTranslationResponse
from .segment_update_response import SegmentUpdateResponse
from .send_text import SendText
from .share_option_response_model import ShareOptionResponseModel
from .share_option_response_model_type import ShareOptionResponseModelType
from .sip_trunk_credentials import SipTrunkCredentials
from .speaker_response_model import SpeakerResponseModel
from .speaker_segment import SpeakerSegment
from .speaker_separation_response_model import SpeakerSeparationResponseModel
from .speaker_separation_response_model_status import SpeakerSeparationResponseModelStatus
from .speaker_track import SpeakerTrack
from .speech_history_item_response import SpeechHistoryItemResponse
from .speech_history_item_response_model_source import SpeechHistoryItemResponseModelSource
from .speech_history_item_response_model_voice_category import SpeechHistoryItemResponseModelVoiceCategory
from .speech_to_text_character_response_model import SpeechToTextCharacterResponseModel
from .speech_to_text_chunk_response_model import SpeechToTextChunkResponseModel
from .speech_to_text_word_response_model import SpeechToTextWordResponseModel
from .speech_to_text_word_response_model_type import SpeechToTextWordResponseModelType
from .streaming_audio_chunk_with_timestamps_response_model import StreamingAudioChunkWithTimestampsResponseModel
from .subscription import Subscription
from .subscription_response import SubscriptionResponse
from .subscription_response_model_billing_period import SubscriptionResponseModelBillingPeriod
from .subscription_response_model_character_refresh_period import SubscriptionResponseModelCharacterRefreshPeriod
from .subscription_response_model_currency import SubscriptionResponseModelCurrency
from .subscription_status import SubscriptionStatus
from .subscription_usage_response_model import SubscriptionUsageResponseModel
from .system_tool_config import SystemToolConfig
from .telephony_provider import TelephonyProvider
from .text_to_speech_as_stream_request import TextToSpeechAsStreamRequest
from .tts_conversational_config import TtsConversationalConfig
from .tts_conversational_config_override import TtsConversationalConfigOverride
from .tts_conversational_config_override_config import TtsConversationalConfigOverrideConfig
from .tts_conversational_model import TtsConversationalModel
from .tts_optimize_streaming_latency import TtsOptimizeStreamingLatency
from .tts_output_format import TtsOutputFormat
from .turn_config import TurnConfig
from .turn_mode import TurnMode
from .twilio_outbound_call_response import TwilioOutboundCallResponse
from .update_workspace_member_response_model import UpdateWorkspaceMemberResponseModel
from .url_avatar import UrlAvatar
from .usage_characters_response_model import UsageCharactersResponseModel
from .user import User
from .user_feedback import UserFeedback
from .user_feedback_score import UserFeedbackScore
from .utterance_response_model import UtteranceResponseModel
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .verification_attempt_response import VerificationAttemptResponse
from .verified_voice_language_response_model import VerifiedVoiceLanguageResponseModel
from .voice import Voice
from .voice_generation_parameter_option_response import VoiceGenerationParameterOptionResponse
from .voice_generation_parameter_response import VoiceGenerationParameterResponse
from .voice_preview_response_model import VoicePreviewResponseModel
from .voice_previews_response_model import VoicePreviewsResponseModel
from .voice_response_model_category import VoiceResponseModelCategory
from .voice_response_model_safety_control import VoiceResponseModelSafetyControl
from .voice_sample import VoiceSample
from .voice_settings import VoiceSettings
from .voice_sharing_moderation_check_response_model import VoiceSharingModerationCheckResponseModel
from .voice_sharing_response import VoiceSharingResponse
from .voice_sharing_response_model_category import VoiceSharingResponseModelCategory
from .voice_sharing_state import VoiceSharingState
from .voice_verification_response import VoiceVerificationResponse
from .webhook_tool_api_schema_config_input import WebhookToolApiSchemaConfigInput
from .webhook_tool_api_schema_config_input_method import WebhookToolApiSchemaConfigInputMethod
from .webhook_tool_api_schema_config_input_request_headers_value import (
    WebhookToolApiSchemaConfigInputRequestHeadersValue,
)
from .webhook_tool_api_schema_config_output import WebhookToolApiSchemaConfigOutput
from .webhook_tool_api_schema_config_output_method import WebhookToolApiSchemaConfigOutputMethod
from .webhook_tool_api_schema_config_output_request_headers_value import (
    WebhookToolApiSchemaConfigOutputRequestHeadersValue,
)
from .webhook_tool_config_input import WebhookToolConfigInput
from .webhook_tool_config_output import WebhookToolConfigOutput
from .widget_config import WidgetConfig
from .widget_config_avatar import (
    WidgetConfigAvatar,
    WidgetConfigAvatar_Image,
    WidgetConfigAvatar_Orb,
    WidgetConfigAvatar_Url,
)
from .widget_config_response_model import WidgetConfigResponseModel
from .widget_config_response_model_avatar import (
    WidgetConfigResponseModelAvatar,
    WidgetConfigResponseModelAvatar_Image,
    WidgetConfigResponseModelAvatar_Orb,
    WidgetConfigResponseModelAvatar_Url,
)
from .widget_expandable import WidgetExpandable
from .widget_feedback_mode import WidgetFeedbackMode
from .workspace_group_by_name_response_model import WorkspaceGroupByNameResponseModel
from .workspace_resource_type import WorkspaceResourceType

__all__ = [
    "Accent",
    "AddAgentSecretResponseModel",
    "AddChapterResponseModel",
    "AddKnowledgeBaseResponseModel",
    "AddProjectResponseModel",
    "AddPronunciationDictionaryResponseModel",
    "AddPronunciationDictionaryRulesResponseModel",
    "AddSharingVoiceRequest",
    "AddVoiceIvcResponseModel",
    "AddVoiceResponseModel",
    "AddWorkspaceGroupMemberResponseModel",
    "AddWorkspaceInviteResponseModel",
    "Age",
    "AgentBan",
    "AgentCallLimits",
    "AgentConfigApiModelInput",
    "AgentConfigApiModelOutput",
    "AgentConfigOverride",
    "AgentConfigOverrideConfig",
    "AgentMetadataResponseModel",
    "AgentPlatformSettingsRequestModel",
    "AgentPlatformSettingsResponseModel",
    "AgentSummaryResponseModel",
    "AgentWorkspaceOverridesInput",
    "AgentWorkspaceOverridesOutput",
    "AllowlistItem",
    "ArrayJsonSchemaPropertyInput",
    "ArrayJsonSchemaPropertyInputItems",
    "ArrayJsonSchemaPropertyOutput",
    "ArrayJsonSchemaPropertyOutputItems",
    "AsrConversationalConfig",
    "AsrInputFormat",
    "AsrProvider",
    "AsrQuality",
    "AudioNativeCreateProjectResponseModel",
    "AudioNativeEditContentResponseModel",
    "AudioNativeProjectSettingsResponseModel",
    "AudioOutput",
    "AudioWithTimestampsResponseModel",
    "AuthSettings",
    "AuthorizationMethod",
    "BanReasonType",
    "BodyAddToKnowledgeBaseV1ConvaiAddToKnowledgeBasePost",
    "BodyAddToKnowledgeBaseV1ConvaiAgentsAgentIdAddToKnowledgeBasePost",
    "BreakdownTypes",
    "ChapterContentBlockExtendableNodeResponseModel",
    "ChapterContentBlockInputModel",
    "ChapterContentBlockResponseModel",
    "ChapterContentBlockResponseModelNodesItem",
    "ChapterContentBlockResponseModelNodesItem_Other",
    "ChapterContentBlockResponseModelNodesItem_TtsNode",
    "ChapterContentBlockTtsNodeResponseModel",
    "ChapterContentInputModel",
    "ChapterContentParagraphTtsNodeInputModel",
    "ChapterContentResponseModel",
    "ChapterResponse",
    "ChapterSnapshotExtendedResponseModel",
    "ChapterSnapshotResponse",
    "ChapterSnapshotsResponse",
    "ChapterState",
    "ChapterStatisticsResponse",
    "ChapterWithContentResponseModel",
    "ChapterWithContentResponseModelState",
    "CharacterAlignmentModel",
    "CharacterAlignmentResponseModel",
    "ClientEvent",
    "ClientToolConfigInput",
    "ClientToolConfigOutput",
    "CloseConnection",
    "ConvAiSecretLocator",
    "ConvAiStoredSecretDependencies",
    "ConvAiStoredSecretDependenciesAgentToolsItem",
    "ConvAiStoredSecretDependenciesAgentToolsItem_Available",
    "ConvAiStoredSecretDependenciesAgentToolsItem_Unknown",
    "ConvAiStoredSecretDependenciesToolsItem",
    "ConvAiStoredSecretDependenciesToolsItem_Available",
    "ConvAiStoredSecretDependenciesToolsItem_Unknown",
    "ConvAiWebhooks",
    "ConvAiWorkspaceStoredSecretConfig",
    "ConversationChargingCommonModel",
    "ConversationConfig",
    "ConversationConfigClientOverrideConfigInput",
    "ConversationConfigClientOverrideConfigOutput",
    "ConversationConfigClientOverrideInput",
    "ConversationConfigClientOverrideOutput",
    "ConversationDeletionSettings",
    "ConversationHistoryAnalysisCommonModel",
    "ConversationHistoryEvaluationCriteriaResultCommonModel",
    "ConversationHistoryFeedbackCommonModel",
    "ConversationHistoryMetadataCommonModel",
    "ConversationHistoryMetadataCommonModelPhoneCall",
    "ConversationHistoryMetadataCommonModelPhoneCall_Twilio",
    "ConversationHistoryTranscriptCommonModel",
    "ConversationHistoryTranscriptCommonModelRole",
    "ConversationHistoryTranscriptToolCallCommonModel",
    "ConversationHistoryTranscriptToolResultCommonModel",
    "ConversationHistoryTwilioPhoneCallModel",
    "ConversationHistoryTwilioPhoneCallModelDirection",
    "ConversationInitiationClientDataConfigInput",
    "ConversationInitiationClientDataConfigOutput",
    "ConversationInitiationClientDataRequestInput",
    "ConversationInitiationClientDataRequestInputDynamicVariablesValue",
    "ConversationInitiationClientDataRequestOutput",
    "ConversationInitiationClientDataRequestOutputDynamicVariablesValue",
    "ConversationInitiationClientDataWebhook",
    "ConversationInitiationClientDataWebhookRequestHeadersValue",
    "ConversationSignedUrlResponseModel",
    "ConversationSummaryResponseModel",
    "ConversationSummaryResponseModelStatus",
    "ConversationTokenDbModel",
    "ConversationTokenPurpose",
    "ConversationTurnMetrics",
    "ConversationalConfigApiModelInput",
    "ConversationalConfigApiModelOutput",
    "ConvertChapterResponseModel",
    "ConvertProjectResponseModel",
    "CreateAgentResponseModel",
    "CreateAudioNativeProjectRequest",
    "CreatePhoneNumberResponseModel",
    "CreatePronunciationDictionaryResponseModel",
    "CreateSipTrunkPhoneNumberRequest",
    "CreateTwilioPhoneNumberRequest",
    "Currency",
    "CustomLlm",
    "DataCollectionResultCommonModel",
    "DeleteChapterResponseModel",
    "DeleteDubbingResponseModel",
    "DeleteHistoryItemResponse",
    "DeleteProjectResponseModel",
    "DeleteSampleResponseModel",
    "DeleteVoiceResponseModel",
    "DeleteWorkspaceGroupMemberResponseModel",
    "DeleteWorkspaceInviteResponseModel",
    "DependentAvailableAgentIdentifier",
    "DependentAvailableAgentIdentifierAccessLevel",
    "DependentAvailableAgentToolIdentifier",
    "DependentAvailableAgentToolIdentifierAccessLevel",
    "DependentAvailableToolIdentifier",
    "DependentAvailableToolIdentifierAccessLevel",
    "DependentPhoneNumberIdentifier",
    "DependentUnknownAgentIdentifier",
    "DependentUnknownAgentToolIdentifier",
    "DependentUnknownToolIdentifier",
    "DoDubbingResponse",
    "DocumentUsageModeEnum",
    "DubbedSegment",
    "DubbingMediaMetadata",
    "DubbingMediaReference",
    "DubbingMetadataResponse",
    "DubbingResource",
    "DynamicVariablesConfig",
    "DynamicVariablesConfigDynamicVariablePlaceholdersValue",
    "EditChapterResponseModel",
    "EditProjectResponseModel",
    "EditVoiceResponseModel",
    "EditVoiceSettingsResponseModel",
    "EmbedVariant",
    "EmbeddingModelEnum",
    "EvaluationSettings",
    "EvaluationSuccessResult",
    "ExtendedSubscriptionResponseModelBillingPeriod",
    "ExtendedSubscriptionResponseModelCharacterRefreshPeriod",
    "ExtendedSubscriptionResponseModelCurrency",
    "FeedbackItem",
    "FineTuningResponse",
    "FineTuningResponseModelStateValue",
    "Gender",
    "GenerationConfig",
    "GetAgentEmbedResponseModel",
    "GetAgentLinkResponseModel",
    "GetAgentResponseModel",
    "GetAgentsPageResponseModel",
    "GetAudioNativeProjectSettingsResponseModel",
    "GetChaptersResponse",
    "GetConvAiSettingsResponseModel",
    "GetConversationResponseModel",
    "GetConversationResponseModelStatus",
    "GetConversationsPageResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown",
    "GetKnowledgeBaseFileResponseModel",
    "GetKnowledgeBaseListResponseModel",
    "GetKnowledgeBaseListResponseModelDocumentsItem",
    "GetKnowledgeBaseListResponseModelDocumentsItem_File",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Url",
    "GetKnowledgeBaseSummaryFileResponseModel",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryUrlResponseModel",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseUrlResponseModel",
    "GetLibraryVoicesResponse",
    "GetPhoneNumberResponseModel",
    "GetProjectsResponse",
    "GetPronunciationDictionariesMetadataResponseModel",
    "GetPronunciationDictionaryMetadataResponse",
    "GetSpeechHistoryResponse",
    "GetVoicesResponse",
    "GetVoicesV2ResponseModel",
    "GetWorkspaceSecretsResponseModel",
    "HistoryAlignmentResponseModel",
    "HistoryAlignmentsResponseModel",
    "HistoryItem",
    "HttpValidationError",
    "ImageAvatar",
    "InitializeConnection",
    "Invoice",
    "KnowledgeBaseDocumentChunkResponseModel",
    "KnowledgeBaseDocumentMetadataResponseModel",
    "KnowledgeBaseLocator",
    "KnowledgeBaseLocatorType",
    "LanguageAddedResponse",
    "LanguagePresetInput",
    "LanguagePresetOutput",
    "LanguagePresetTranslation",
    "LanguageResponse",
    "LibraryVoiceResponse",
    "LibraryVoiceResponseModelCategory",
    "LiteralJsonSchemaProperty",
    "LiteralJsonSchemaPropertyConstantValue",
    "LiteralJsonSchemaPropertyType",
    "Llm",
    "ManualVerificationFileResponse",
    "ManualVerificationResponse",
    "MetricRecord",
    "Model",
    "ModelRatesResponseModel",
    "ModelResponseModelConcurrencyGroup",
    "ModerationStatusResponseModel",
    "ModerationStatusResponseModelSafetyStatus",
    "ModerationStatusResponseModelWarningStatus",
    "NormalizedAlignment",
    "ObjectJsonSchemaPropertyInput",
    "ObjectJsonSchemaPropertyInputPropertiesValue",
    "ObjectJsonSchemaPropertyOutput",
    "ObjectJsonSchemaPropertyOutputPropertiesValue",
    "OrbAvatar",
    "OutputFormat",
    "PhoneNumberAgentInfo",
    "PodcastBulletinMode",
    "PodcastBulletinModeData",
    "PodcastConversationMode",
    "PodcastConversationModeData",
    "PodcastProjectResponseModel",
    "PodcastTextSource",
    "PodcastUrlSource",
    "PostAgentAvatarResponseModel",
    "PostWorkspaceSecretResponseModel",
    "PrivacyConfig",
    "ProfilePageResponseModel",
    "ProjectCreationMetaResponseModel",
    "ProjectCreationMetaResponseModelStatus",
    "ProjectCreationMetaResponseModelType",
    "ProjectExtendedResponseModel",
    "ProjectExtendedResponseModelAccessLevel",
    "ProjectExtendedResponseModelApplyTextNormalization",
    "ProjectExtendedResponseModelFiction",
    "ProjectExtendedResponseModelQualityPreset",
    "ProjectExtendedResponseModelSourceType",
    "ProjectExtendedResponseModelTargetAudience",
    "ProjectResponse",
    "ProjectResponseModelAccessLevel",
    "ProjectResponseModelFiction",
    "ProjectResponseModelSourceType",
    "ProjectResponseModelTargetAudience",
    "ProjectSnapshotExtendedResponseModel",
    "ProjectSnapshotResponse",
    "ProjectSnapshotsResponse",
    "ProjectState",
    "PromptAgentInput",
    "PromptAgentInputToolsItem",
    "PromptAgentInputToolsItem_Client",
    "PromptAgentInputToolsItem_System",
    "PromptAgentInputToolsItem_Webhook",
    "PromptAgentOutput",
    "PromptAgentOutputToolsItem",
    "PromptAgentOutputToolsItem_Client",
    "PromptAgentOutputToolsItem_System",
    "PromptAgentOutputToolsItem_Webhook",
    "PromptAgentOverride",
    "PromptAgentOverrideConfig",
    "PromptEvaluationCriteria",
    "PronunciationDictionaryAliasRuleRequestModel",
    "PronunciationDictionaryPhonemeRuleRequestModel",
    "PronunciationDictionaryVersionLocator",
    "PronunciationDictionaryVersionResponseModel",
    "PydanticPronunciationDictionaryVersionLocator",
    "QueryParamsJsonSchema",
    "RagChunkMetadata",
    "RagConfig",
    "RagIndexResponseModel",
    "RagIndexStatus",
    "RagRetrievalInfo",
    "ReaderResourceResponseModel",
    "ReaderResourceResponseModelResourceType",
    "RealtimeVoiceSettings",
    "RecordingResponse",
    "RemovePronunciationDictionaryRulesResponseModel",
    "ResourceAccessInfo",
    "ResourceAccessInfoRole",
    "ResourceMetadataResponseModel",
    "ReviewStatus",
    "SafetyCommonModel",
    "SafetyEvaluation",
    "SafetyResponseModel",
    "SafetyRule",
    "SecretDependencyType",
    "SegmentCreateResponse",
    "SegmentDeleteResponse",
    "SegmentDubResponse",
    "SegmentTranscriptionResponse",
    "SegmentTranslationResponse",
    "SegmentUpdateResponse",
    "SendText",
    "ShareOptionResponseModel",
    "ShareOptionResponseModelType",
    "SipTrunkCredentials",
    "SpeakerResponseModel",
    "SpeakerSegment",
    "SpeakerSeparationResponseModel",
    "SpeakerSeparationResponseModelStatus",
    "SpeakerTrack",
    "SpeechHistoryItemResponse",
    "SpeechHistoryItemResponseModelSource",
    "SpeechHistoryItemResponseModelVoiceCategory",
    "SpeechToTextCharacterResponseModel",
    "SpeechToTextChunkResponseModel",
    "SpeechToTextWordResponseModel",
    "SpeechToTextWordResponseModelType",
    "StreamingAudioChunkWithTimestampsResponseModel",
    "Subscription",
    "SubscriptionResponse",
    "SubscriptionResponseModelBillingPeriod",
    "SubscriptionResponseModelCharacterRefreshPeriod",
    "SubscriptionResponseModelCurrency",
    "SubscriptionStatus",
    "SubscriptionUsageResponseModel",
    "SystemToolConfig",
    "TelephonyProvider",
    "TextToSpeechAsStreamRequest",
    "TtsConversationalConfig",
    "TtsConversationalConfigOverride",
    "TtsConversationalConfigOverrideConfig",
    "TtsConversationalModel",
    "TtsOptimizeStreamingLatency",
    "TtsOutputFormat",
    "TurnConfig",
    "TurnMode",
    "TwilioOutboundCallResponse",
    "UpdateWorkspaceMemberResponseModel",
    "UrlAvatar",
    "UsageCharactersResponseModel",
    "User",
    "UserFeedback",
    "UserFeedbackScore",
    "UtteranceResponseModel",
    "ValidationError",
    "ValidationErrorLocItem",
    "VerificationAttemptResponse",
    "VerifiedVoiceLanguageResponseModel",
    "Voice",
    "VoiceGenerationParameterOptionResponse",
    "VoiceGenerationParameterResponse",
    "VoicePreviewResponseModel",
    "VoicePreviewsResponseModel",
    "VoiceResponseModelCategory",
    "VoiceResponseModelSafetyControl",
    "VoiceSample",
    "VoiceSettings",
    "VoiceSharingModerationCheckResponseModel",
    "VoiceSharingResponse",
    "VoiceSharingResponseModelCategory",
    "VoiceSharingState",
    "VoiceVerificationResponse",
    "WebhookToolApiSchemaConfigInput",
    "WebhookToolApiSchemaConfigInputMethod",
    "WebhookToolApiSchemaConfigInputRequestHeadersValue",
    "WebhookToolApiSchemaConfigOutput",
    "WebhookToolApiSchemaConfigOutputMethod",
    "WebhookToolApiSchemaConfigOutputRequestHeadersValue",
    "WebhookToolConfigInput",
    "WebhookToolConfigOutput",
    "WidgetConfig",
    "WidgetConfigAvatar",
    "WidgetConfigAvatar_Image",
    "WidgetConfigAvatar_Orb",
    "WidgetConfigAvatar_Url",
    "WidgetConfigResponseModel",
    "WidgetConfigResponseModelAvatar",
    "WidgetConfigResponseModelAvatar_Image",
    "WidgetConfigResponseModelAvatar_Orb",
    "WidgetConfigResponseModelAvatar_Url",
    "WidgetExpandable",
    "WidgetFeedbackMode",
    "WorkspaceGroupByNameResponseModel",
    "WorkspaceResourceType",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
from .subscription_response import SubscriptionResponse
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class User(UncheckedBaseModel):
    user_id: str = pydantic.Field()
    """
    The unique identifier of the user.
    """

    subscription: SubscriptionResponse = pydantic.Field()
    """
    Details of the user's subscription.
    """

    subscription_extras: typing.Optional[typing.Optional[typing.Any]] = pydantic.Field(default=None)
    """
    Optional additional details about the user's subscription.
    """

    is_new_user: bool = pydantic.Field()
    """
    Whether the user is new.
    """

    xi_api_key: typing.Optional[str] = pydantic.Field(default=None)
    """
    The API key of the user.
    """

    can_use_delayed_payment_methods: bool = pydantic.Field()
    """
    Whether the user can use delayed payment methods.
    """

    is_onboarding_completed: bool = pydantic.Field()
    """
    Whether the user's onboarding is completed.
    """

    is_onboarding_checklist_completed: bool = pydantic.Field()
    """
    Whether the user's onboarding checklist is completed.
    """

    first_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    First name of the user.
    """

    is_api_key_hashed: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the user's API key is hashed.
    """

    xi_api_key_preview: typing.Optional[str] = pydantic.Field(default=None)
    """
    The preview of the user's API key.
    """

    referral_link_code: typing.Optional[str] = pydantic.Field(default=None)
    """
    The referral link code of the user.
    """

    partnerstack_partner_default_link: typing.Optional[str] = pydantic.Field(default=None)
    """
    The Partnerstack partner default link of the user.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .moderation_status_response_model_safety_status import (
    ModerationStatusResponseModelSafetyStatus,
)
from .moderation_status_response_model_warning_status import (
    ModerationStatusResponseModelWarningStatus,
)
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ModerationStatusResponseModel(UncheckedBaseModel):
    is_in_probation: bool = pydantic.Field()
    """
    Whether the user is in probation.
    """

    enterprise_check_nogo_voice: bool = pydantic.Field()
    """
    Whether the user's enterprise check nogo voice is enabled.
    """

    enterprise_check_block_nogo_voice: bool = pydantic.Field()
    """
    Whether the user's enterprise check block nogo voice is enabled.
    """

    never_live_moderate: bool = pydantic.Field()
    """
    Whether the user's never live moderate is enabled.
    """

    nogo_voice_similar_voice_upload_count: int = pydantic.Field()
    """
    The number of similar voice uploads that have been blocked.
    """

    enterprise_background_moderation_enabled: bool = pydantic.Field()
    """
    Whether the user's enterprise background moderation is enabled.
    """

    safety_status: typing.Optional[ModerationStatusResponseModelSafetyStatus] = pydantic.Field(default=None)
    """
    The safety status of the user.
    """

    warning_status: typing.Optional[ModerationStatusResponseModelWarningStatus] = pydantic.Field(default=None)
    """
    The warning status of the user.
    """

    on_watchlist: bool = pydantic.Field()
    """
    Whether the user is on the watchlist.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization = (
    typing.Union[typing.Literal["auto", "on", "off"], typing.Any]
)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
import typing
from .literal_json_schema_property import LiteralJsonSchemaProperty
import typing

if typing.TYPE_CHECKING:
    from .object_json_schema_property_input import ObjectJsonSchemaPropertyInput
    from .array_json_schema_property_input import ArrayJsonSchemaPropertyInput
ObjectJsonSchemaPropertyInputPropertiesValue = typing.Union[
    LiteralJsonSchemaProperty,
    "ObjectJsonSchemaPropertyInput",
    "ArrayJsonSchemaPropertyInput",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .project_response import ProjectResponse
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class GetProjectsResponse(UncheckedBaseModel):
    projects: typing.List[ProjectResponse] = pydantic.Field()
    """
    A list of projects with their metadata.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .dubbing_media_reference import DubbingMediaReference
from .speaker_track import SpeakerTrack
from .speaker_segment import SpeakerSegment
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class DubbingResource(UncheckedBaseModel):
    id: str
    version: int
    source_language: str
    target_languages: typing.List[str]
    background: DubbingMediaReference
    foreground: DubbingMediaReference
    speaker_tracks: typing.Dict[str, SpeakerTrack]
    speaker_segments: typing.Dict[str, SpeakerSegment]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .extended_subscription_response_model_currency import (
    ExtendedSubscriptionResponseModelCurrency,
)
from .subscription_status import SubscriptionStatus
from .extended_subscription_response_model_billing_period import (
    ExtendedSubscriptionResponseModelBillingPeriod,
)
from .extended_subscription_response_model_character_refresh_period import (
    ExtendedSubscriptionResponseModelCharacterRefreshPeriod,
)
from .invoice import Invoice
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class Subscription(UncheckedBaseModel):
    tier: str = pydantic.Field()
    """
    The tier of the user's subscription.
    """

    character_count: int = pydantic.Field()
    """
    The number of characters used by the user.
    """

    character_limit: int = pydantic.Field()
    """
    The maximum number of characters allowed in the current billing period.
    """

    can_extend_character_limit: bool = pydantic.Field()
    """
    Whether the user can extend their character limit.
    """

    allowed_to_extend_character_limit: bool = pydantic.Field()
    """
    Whether the user is allowed to extend their character limit.
    """

    next_character_count_reset_unix: typing.Optional[int] = pydantic.Field(default=None)
    """
    The Unix timestamp of the next character count reset.
    """

    voice_slots_used: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of voice slots used by the user.
    """

    voice_limit: int = pydantic.Field()
    """
    The maximum number of voice slots allowed for the user.
    """

    max_voice_add_edits: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum number of voice add/edits allowed for the user.
    """

    voice_add_edit_counter: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of voice add/edits used by the user.
    """

    professional_voice_limit: int = pydantic.Field()
    """
    The maximum number of professional voices allowed for the user.
    """

    can_extend_voice_limit: bool = pydantic.Field()
    """
    Whether the user can extend their voice limit.
    """

    can_use_instant_voice_cloning: bool = pydantic.Field()
    """
    Whether the user can use instant voice cloning.
    """

    can_use_professional_voice_cloning: bool = pydantic.Field()
    """
    Whether the user can use professional voice cloning.
    """

    currency: typing.Optional[ExtendedSubscriptionResponseModelCurrency] = pydantic.Field(default=None)
    """
    The currency of the user's subscription.
    """

    status: typing.Optional[SubscriptionStatus] = pydantic.Field(default=None)
    """
    The status of the user's subscription.
    """

    billing_period: typing.Optional[ExtendedSubscriptionResponseModelBillingPeriod] = pydantic.Field(default=None)
    """
    The billing period of the user's subscription.
    """

    character_refresh_period: typing.Optional[ExtendedSubscriptionResponseModelCharacterRefreshPeriod] = pydantic.Field(
        default=None
    )
    """
    The character refresh period of the user's subscription.
    """

    next_invoice: typing.Optional[Invoice] = pydantic.Field(default=None)
    """
    The next invoice for the user.
    """

    has_open_invoices: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the user has open invoices.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

SpeechToTextConvertRequestTimestampsGranularity = typing.Union[typing.Literal["none", "word", "character"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .conversation_initiation_client_data_webhook import (
    ConversationInitiationClientDataWebhook,
)
from .conv_ai_webhooks import ConvAiWebhooks
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetConvAiSettingsResponseModel(UncheckedBaseModel):
    conversation_initiation_client_data_webhook: typing.Optional[ConversationInitiationClientDataWebhook] = None
    webhooks: typing.Optional[ConvAiWebhooks] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
